==> haskell-base-orphans-0.5.3-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-base-orphans/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-orphans
version: 0.5.3
id: base-orphans-0.5.3-27215a9428d23686c8514fbd3bba8ccb
key: baseo_4lH3gPOjJvdDgDLhAat0cc
license: MIT
copyright: (c) 2012-2016 Simon Hengel,
           (c) 2014-2016 João Cristóvão,
           (c) 2015-2016 Ryan Scott
maintainer: Simon Hengel <sol@typeful.net>,
            João Cristóvão <jmacristovao@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
homepage: https://github.com/haskell-compat/base-orphans#readme
synopsis: Backwards-compatible orphan instances for base
description:
    @base-orphans@ defines orphan instances that mimic instances available in later versions of @base@ to a wider (older) range of compilers. @base-orphans@ does not export anything except the orphan instances themselves and complements @<http://hackage.haskell.org/package/base-compat base-compat>@.
    See the README for what instances are covered: <https://github.com/haskell-compat/base-orphans#readme>. See also the <https://github.com/haskell-compat/base-orphans#what-is-not-covered what is not covered> section.
category: Compatibility
author: Simon Hengel <sol@typeful.net>,
        João Cristóvão <jmacristovao@gmail.com>,
        Ryan Scott <ryan.gl.scott@gmail.com>
exposed: True
exposed-modules:
    Data.Orphans
hidden-modules: Data.Orphans.Prelude
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/base-orphans-0.5.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/base-orphans-0.5.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/base-orphans-0.5.3
hs-libraries: HSbase-orphans-0.5.3-4lH3gPOjJvdDgDLhAat0cc
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
haddock-interfaces: /usr/share/doc/haskell-base-orphans/html/base-orphans.haddock
haddock-html: /usr/share/doc/haskell-base-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-orphans-0.5.4-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-base-orphans/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-orphans
version: 0.5.4
id: base-orphans-0.5.4-e40139ef3f9e9946a3f68f9fef66a420
key: baseo_0gFtKFBT26OGSKHmmdqdfx
license: MIT
copyright: (c) 2012-2016 Simon Hengel,
           (c) 2014-2016 João Cristóvão,
           (c) 2015-2016 Ryan Scott
maintainer: Simon Hengel <sol@typeful.net>,
            João Cristóvão <jmacristovao@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
homepage: https://github.com/haskell-compat/base-orphans#readme
synopsis: Backwards-compatible orphan instances for base
description:
    @base-orphans@ defines orphan instances that mimic instances available in later versions of @base@ to a wider (older) range of compilers. @base-orphans@ does not export anything except the orphan instances themselves and complements @<http://hackage.haskell.org/package/base-compat base-compat>@.
    See the README for what instances are covered: <https://github.com/haskell-compat/base-orphans#readme>. See also the <https://github.com/haskell-compat/base-orphans#what-is-not-covered what is not covered> section.
category: Compatibility
author: Simon Hengel <sol@typeful.net>,
        João Cristóvão <jmacristovao@gmail.com>,
        Ryan Scott <ryan.gl.scott@gmail.com>
exposed: True
exposed-modules:
    Data.Orphans
hidden-modules: Data.Orphans.Prelude
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/base-orphans-0.5.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/base-orphans-0.5.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/base-orphans-0.5.4
hs-libraries: HSbase-orphans-0.5.4-0gFtKFBT26OGSKHmmdqdfx
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
haddock-interfaces: /usr/share/doc/haskell-base-orphans/html/base-orphans.haddock
haddock-html: /usr/share/doc/haskell-base-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
